@@ -9,6 +9,8 @@
  * the LICENSE file that was distributed with this source code.
  */
 
+declare(strict_types=1);
+
 namespace Composer\XdebugHandler;
 
 use Composer\Pcre\Preg;
@@ -79,9 +81,9 @@ class XdebugHandler
      * @param string $envPrefix Value used in environment variables
      * @throws \RuntimeException If the parameter is invalid
      */
-    public function __construct($envPrefix)
+    public function __construct(string $envPrefix)
     {
-        if (!is_string($envPrefix) || $envPrefix === '') {
+        if ($envPrefix === '') {
             throw new \RuntimeException('Invalid constructor parameter');
         }
 
@@ -101,12 +103,8 @@ class XdebugHandler
 
     /**
      * Activates status message output to a PSR3 logger
-     *
-     * @param LoggerInterface $logger
-     *
-     * @return $this
      */
-    public function setLogger(LoggerInterface $logger)
+    public function setLogger(LoggerInterface $logger): self
     {
         $this->statusWriter->setLogger($logger);
         return $this;
@@ -114,12 +112,8 @@ class XdebugHandler
 
     /**
      * Sets the main script location if it cannot be called from argv
-     *
-     * @param string $script
-     *
-     * @return $this
      */
-    public function setMainScript($script)
+    public function setMainScript(string $script): self
     {
         $this->script = $script;
         return $this;
@@ -127,10 +121,8 @@ class XdebugHandler
 
     /**
      * Persist the settings to keep Xdebug out of sub-processes
-     *
-     * @return $this
      */
-    public function setPersistent()
+    public function setPersistent(): self
     {
         $this->persistent = true;
         return $this;
@@ -142,10 +134,8 @@ class XdebugHandler
      * This behaviour can be disabled by setting the MYAPP_ALLOW_XDEBUG
      * environment variable to 1. This variable is used internally so that
      * the restarted process is created only once.
-     *
-     * @return void
      */
-    public function check()
+    public function check(): void
     {
         $this->notify(Status::CHECK, self::$xdebugVersion.'|'.self::$xdebugMode);
         $envArgs = explode('|', (string) getenv($this->envAllowXdebug));
@@ -197,7 +187,7 @@ class XdebugHandler
      *
      * @return string[]
      */
-    public static function getAllIniFiles()
+    public static function getAllIniFiles(): array
     {
         if (self::$name !== null) {
             $env = getenv(self::$name.self::SUFFIX_INIS);
@@ -207,7 +197,7 @@ class XdebugHandler
             }
         }
 
-        $paths = array((string) php_ini_loaded_file());
+        $paths = [(string) php_ini_loaded_file()];
         $scanned = php_ini_scanned_files();
 
         if ($scanned !== false) {
@@ -223,10 +213,9 @@ class XdebugHandler
      * Settings will be available if the current process was restarted, or
      * called with the settings from an existing restart.
      *
-     * @return array|null
      * @phpstan-return restartData|null
      */
-    public static function getRestartSettings()
+    public static function getRestartSettings(): ?array
     {
         $envArgs = explode('|', (string) getenv(self::RESTART_SETTINGS));
 
@@ -235,22 +224,20 @@ class XdebugHandler
             return null;
         }
 
-        return array(
+        return [
             'tmpIni' => $envArgs[0],
             'scannedInis' => (bool) $envArgs[1],
             'scanDir' => '*' === $envArgs[2] ? false : $envArgs[2],
             'phprc' => '*' === $envArgs[3] ? false : $envArgs[3],
             'inis' => explode(PATH_SEPARATOR, $envArgs[4]),
             'skipped' => $envArgs[5],
-        );
+        ];
     }
 
     /**
      * Returns the Xdebug version that triggered a successful restart
-     *
-     * @return string
      */
-    public static function getSkippedVersion()
+    public static function getSkippedVersion(): string
     {
         return (string) self::$skipped;
     }
@@ -260,10 +247,8 @@ class XdebugHandler
      *
      * true: if Xdebug is loaded and is running in an active mode.
      * false: if Xdebug is not loaded, or it is running with xdebug.mode=off.
-     *
-     * @return bool
      */
-    public static function isXdebugActive()
+    public static function isXdebugActive(): bool
     {
         self::setXdebugDetails();
         return self::$xdebugActive;
@@ -273,13 +258,8 @@ class XdebugHandler
      * Allows an extending class to decide if there should be a restart
      *
      * The default is to restart if Xdebug is loaded and its mode is not "off".
-     * Do not typehint for 1.x compatibility.
-     *
-     * @param bool $default The default behaviour
-     *
-     * @return bool Whether the process should restart
      */
-    protected function requiresRestart($default)
+    protected function requiresRestart(bool $default): bool
     {
         return $default;
     }
@@ -287,13 +267,9 @@ class XdebugHandler
     /**
      * Allows an extending class to access the tmpIni
      *
-     * Do not typehint for 1.x compatibility
-     *
-     * @param string[] $command
-     *
-     * @return void
+     * @param string[] $command     *
      */
-    protected function restart($command)
+    protected function restart(array $command): void
     {
         $this->doRestart($command);
     }
@@ -302,11 +278,9 @@ class XdebugHandler
      * Executes the restarted command then deletes the tmp ini
      *
      * @param string[] $command
-     *
-     * @return void
      * @phpstan-return never
      */
-    private function doRestart(array $command)
+    private function doRestart(array $command): void
     {
         $this->tryEnableSignals();
         $this->notify(Status::RESTARTING, implode(' ', $command));
@@ -321,7 +295,7 @@ class XdebugHandler
             }
         }
 
-        $process = proc_open($cmd, array(), $pipes);
+        $process = proc_open($cmd, [], $pipes);
         if (is_resource($process)) {
             $exitCode = proc_close($process);
         }
@@ -350,10 +324,8 @@ class XdebugHandler
      * stop potential recursion:
      *   - tmp ini file creation
      *   - environment variable creation
-     *
-     * @return bool
      */
-    private function prepareRestart()
+    private function prepareRestart(): bool
     {
         $error = null;
         $iniFiles = self::getAllIniFiles();
@@ -362,12 +334,8 @@ class XdebugHandler
 
         if (!$this->cli) {
             $error = 'Unsupported SAPI: '.PHP_SAPI;
-        } elseif (!defined('PHP_BINARY')) {
-            $error = 'PHP version is too old: '.PHP_VERSION;
         } elseif (!$this->checkConfiguration($info)) {
             $error = $info;
-        } elseif (!$this->checkScanDirConfig()) {
-            $error = 'PHP version does not report scanned inis: '.PHP_VERSION;
         } elseif (!$this->checkMainScript()) {
             $error = 'Unable to access main script: '.$this->script;
         } elseif (!$this->writeTmpIni($iniFiles, $tmpDir, $error)) {
@@ -387,12 +355,8 @@ class XdebugHandler
      * Returns true if the tmp ini file was written
      *
      * @param string[] $iniFiles All ini files used in the current process
-     * @param string $tmpDir The system temporary directory
-     * @param null|string $error Set by method if ini file cannot be read
-     *
-     * @return bool
      */
-    private function writeTmpIni(array $iniFiles, $tmpDir, &$error)
+    private function writeTmpIni(array $iniFiles, string $tmpDir, ?string &$error): bool
     {
         if (($tmpfile = @tempnam($tmpDir, '')) === false) {
             return false;
@@ -444,9 +408,9 @@ class XdebugHandler
      *
      * @return string[]
      */
-    private function getCommand()
+    private function getCommand(): array
     {
-        $php = array(PHP_BINARY);
+        $php = [PHP_BINARY];
         $args = array_slice($_SERVER['argv'], 1);
 
         if (!$this->persistent) {
@@ -454,7 +418,7 @@ class XdebugHandler
             array_push($php, '-n', '-c', $this->tmpIni);
         }
 
-        return array_merge($php, array($this->script), $args);
+        return array_merge($php, [$this->script], $args);
     }
 
     /**
@@ -462,12 +426,9 @@ class XdebugHandler
      *
      * No need to update $_SERVER since this is set in the restarted process.
      *
-     * @param bool $scannedInis Whether there were scanned ini files
      * @param string[] $iniFiles All ini files used in the current process
-     *
-     * @return bool
      */
-    private function setEnvironment($scannedInis, array $iniFiles)
+    private function setEnvironment(bool $scannedInis, array $iniFiles): bool
     {
         $scanDir = getenv('PHP_INI_SCAN_DIR');
         $phprc = getenv('PHPRC');
@@ -485,26 +446,21 @@ class XdebugHandler
         }
 
         // Flag restarted process and save values for it to use
-        $envArgs = array(
+        $envArgs = [
             self::RESTART_ID,
             self::$xdebugVersion,
             (int) $scannedInis,
             false === $scanDir ? '*' : $scanDir,
             false === $phprc ? '*' : $phprc,
-        );
+        ];
 
         return putenv($this->envAllowXdebug.'='.implode('|', $envArgs));
     }
 
     /**
      * Logs status messages
-     *
-     * @param string $op Status handler constant
-     * @param null|string $data Optional data
-     *
-     * @return void
      */
-    private function notify($op, $data = null)
+    private function notify(string $op, ?string $data = null): void
     {
         $this->statusWriter->report($op, $data);
     }
@@ -515,9 +471,8 @@ class XdebugHandler
      * @param mixed[] $loadedConfig All current ini settings
      * @param mixed[] $iniConfig Settings from user ini files
      *
-     * @return string
      */
-    private function mergeLoadedConfig(array $loadedConfig, array $iniConfig)
+    private function mergeLoadedConfig(array $loadedConfig, array $iniConfig): string
     {
         $content = '';
 
@@ -540,12 +495,10 @@ class XdebugHandler
 
     /**
      * Returns true if the script name can be used
-     *
-     * @return bool
      */
-    private function checkMainScript()
+    private function checkMainScript(): bool
     {
-        if (null !== $this->script) {
+        if ($this->script !== null) {
             // Allow an application to set -- for standard input
             return file_exists($this->script) || '--' === $this->script;
         }
@@ -569,19 +522,17 @@ class XdebugHandler
      * Adds restart settings to the environment
      *
      * @param string[] $envArgs
-     *
-     * @return void
      */
-    private function setEnvRestartSettings($envArgs)
+    private function setEnvRestartSettings(array $envArgs): void
     {
-        $settings = array(
+        $settings = [
             php_ini_loaded_file(),
             $envArgs[2],
             $envArgs[3],
             $envArgs[4],
             getenv($this->envOriginalInis),
             self::$skipped,
-        );
+        ];
 
         Process::setEnv(self::RESTART_SETTINGS, implode('|', $settings));
     }
@@ -589,12 +540,9 @@ class XdebugHandler
     /**
      * Syncs settings and the environment if called with existing settings
      *
-     * @param array $settings
      * @phpstan-param restartData $settings
-     *
-     * @return void
      */
-    private function syncSettings(array $settings)
+    private function syncSettings(array $settings): void
     {
         if (false === getenv($this->envOriginalInis)) {
             // Called by another app, so make original inis available
@@ -605,31 +553,10 @@ class XdebugHandler
         $this->notify(Status::INFO, 'Process called with existing restart settings');
     }
 
-    /**
-     * Returns true if there are scanned inis and PHP is able to report them
-     *
-     * php_ini_scanned_files will fail when PHP_CONFIG_FILE_SCAN_DIR is empty.
-     * Fixed in 7.1.13 and 7.2.1
-     *
-     * @return bool
-     */
-    private function checkScanDirConfig()
-    {
-        if (PHP_VERSION_ID >= 70113 && PHP_VERSION_ID !== 70200) {
-            return true;
-        }
-
-        return ((string) getenv('PHP_INI_SCAN_DIR') === '')
-            || PHP_CONFIG_FILE_SCAN_DIR !== '';
-    }
-
     /**
      * Returns true if there are no known configuration issues
-     *
-     * @param string $info Set by method
-     * @return bool
      */
-    private function checkConfiguration(&$info)
+    private function checkConfiguration(?string &$info): bool
     {
         if (!function_exists('proc_open')) {
             $info = 'proc_open function is disabled';
@@ -668,10 +595,8 @@ class XdebugHandler
      * Enables async signals and control interrupts in the restarted process
      *
      * Available on Unix PHP 7.1+ with the pcntl extension and Windows PHP 7.4+.
-     *
-     * @return void
      */
-    private function tryEnableSignals()
+    private function tryEnableSignals(): void
     {
         if (function_exists('pcntl_async_signals') && function_exists('pcntl_signal')) {
             pcntl_async_signals(true);
@@ -696,10 +621,8 @@ class XdebugHandler
 
     /**
      * Sets static properties $xdebugActive, $xdebugVersion and $xdebugMode
-     *
-     * @return void
      */
-    private static function setXdebugDetails()
+    private static function setXdebugDetails(): void
     {
         if (self::$xdebugActive !== null) {
             return;
@@ -723,6 +646,7 @@ class XdebugHandler
         // See if xdebug.mode is supported in this version
         $iniMode = ini_get('xdebug.mode');
         if ($iniMode === false) {
+            self::$xdebugActive = true;
             return;
         }
 
